==> plesk-billing-6.0.0.tar.gz: plesk-billing-6.0.0/plesk-billing/lib-mbapi/include/modules/gateway/authorizenet.php <==
<?php
// $Id: authorizenet.php 13219 2008-10-09 08:26:26Z mdmitriev $
// +----------------------------------------------------------------------+
// | ModernBill [TM] .:. Client Billing System                            |
// +----------------------------------------------------------------------+
// | Copyright (c) 2001-2006 ModernGigabyte, LLC                          |
// +----------------------------------------------------------------------+
// | This source file is subject to the ModernBill End User License       |
// | Agreement (EULA), that is bundled with this package in the file      |
// | LICENSE, and is available at through the world-wide-web at           |
// | http://www.modernbill.com/extranet/LICENSE.txt                       |
// | If you did not receive a copy of the ModernBill license and are      |
// | unable to obtain it through the world-wide-web, please send a note   |
// | to license@modernbill.com so we can email you a copy immediately.    |
// +----------------------------------------------------------------------+
// | Authors: ModernGigabyte, LLC <info@moderngigabyte.com>               |
// | Support: http://www.modernsupport.com/modernbill/                    |
// +----------------------------------------------------------------------+
// | ModernGigabyte and ModernBill are trademarks of ModernGigabyte, LLC. |
// +----------------------------------------------------------------------+
require_once dirname(__FILE__)."/../../../../lib-tk/shield.php";

require_once mb_path("/lib-mbapi/include/modules/gateway/gateway.php");

/**
 * This class is an instantion of the Gateway class, that executes a command pertaining
 * to comunicating with a payment gateway, in the default case from the database. Pass in
 * only the array parameters that are set.
 *
 *<module>
 * <gateway>
 *  <authorizenet>
 *     <params>
 *       <configGroupName></configGroupName>						(Required: Configuration instance of AuthorizeNet module)
 *       <subCommand>charge</subCommand>       						(Required: One of charge, auth, finalize, refund)
 *       <invoiceID></invoiceID>
 *       <authCode></authCode>										(Required for finalize)
 *       <transactionCode></transactionCode>						(Required for refund)
 *       <paymentDescription></paymentDescription>					(Required)
 *       <paymentAmount></paymentAmount>							(Required: 0.00)
 *       <paymentMethod></paymentMethod>							(Required: CC, echeck)
 *       <isRecurring></isRecurring>								(0,1)
 *       <billingAccountID></billingAccountID>			(Enter either this or billing info below)
 *       <clientContactID></clientContactID>									(Enter either this or contact info below)
 *       <billingCardNum></billingCardNum>
 *       <billingCardExpYear></billingCardExpYear>
 *       <billingCardExpMonth></billingCardExpMonth>
 *       <cardCVV2>222</cardCVV2>
 *       <billingBankName></billingBankName>
 *       <billingBankAbaCode></billingBankAbaCode>
 *       <billingBankAccountNum></billingBankAccountNum>
 *       <billingBankLicenseNum></billingBankLicenseNum>
 *       <billingBankDOB></billingBankDOB>
 *       <contactFirstName></contactFirstName>
 *       <contactLastName></contactLastName>
 *       <contactCompany></contactCompany>
 *       <contactAddress1></contactAddress1>
 *       <contactAddress2></contactAddress2>
 *       <contactCity></contactCity>
 *       <contactState></contactState>
 *       <contactZip></contactZip>
 *       <countriesID></countriesID>
 *       <contactPhone1></contactPhone1>
 *       <contactFax></contactFax>
 *       <contactEmail></contactEmail>
 *     </params>
 *   </authorizenet>
 * </gateway>
 *<module>
 *
 * @package modernbill
 * @subpackage mbapi
 */

$className = "AuthorizeNet";
$GLOBALS["moduleInfo"][$className] = array
(
    "type" => "gateway",
    "status" => "TRANS_STABLE",
    "version" => "1.0.2",
    "gatewaytype" => "1",
    "displayName" => "AuthorizeNet",
    "author" => "ModernGigabyte, LLC",
    "capabilities" => array(GATEWAY_CHARGE, GATEWAY_AUTHORIZE, GATEWAY_PRIOR_AUTH_CHARGE, GATEWAY_REFUND, GATEWAY_PARTIAL_REFUND, GATEWAY_VOID)
);

class AuthorizeNet extends Gateway {

	/**
	 * Returns the module display for the BluePay module. This includes version number and display name.
	 * the columns in config_params. This array will be looped by SetConfigGroups.
	 *
	 * @return	An array of arrays containing all the display info for the module.
	 */
    function getModuleInfo() {
        return $GLOBALS["moduleInfo"]["AuthorizeNet"];
    }

	/**
	 * Execute the command based upon the given information, and return the result.
	 *
	 * @return  The result of the AuthorizeNet gateway command based upon the given information.
	 */
	 function AuthorizeNet($params){
	 $this->stringRep = "authorizenet";
	 	parent::Gateway($params);

        $moduleInfo = $this->getModuleInfo();

        foreach ($moduleInfo["capabilities"] as $cap){
            $this->capabilities[$cap] = 1;
        }
		$this->version = "1.0.0";
		$this->liveURL = "https://secure.authorize.net/gateway/transact.dll";
		$this->testURL = "https://test.authorize.net/gateway/transact.dll";
	 }
	 
	/**
	 * Returns the default configuration parameters for the BluePay module. The number of elements in each array must me identical to 
	 * the columns in config_params. This array will be looped by SetConfigGroups.
	 * 
	 * @return	An array of arrays containing all the parameters the module uses. 
	 */
	function addDefaultConfigParams() {
		static $defaultConfigParams = array(
			array(NULL, NULL, "Login_ID", "testdrive", "", "TRANS_AUTHNET_LOGINID", "TRANS_AUTHNET_LOGINID_DESC", "t", 1, 1, 0, null),
			array(NULL, NULL, "Password", "testdrive", "", "TRANS_AUTHNET_PASSWORD", "TRANS_AUTHNET_PASSWORD_DESC", "p", 1, 2, 0, null),
			array(NULL, NULL, "Version", "3.1", "", "TRANS_AUTHNET_VERSION","TRANS_AUTHNET_VERSION_DESC", "t", 1, 3, 0, null),
			array(NULL, NULL, "Invoice_Description", "", "", "TRANS_INVOICE_DESCRIPTION", "TRANS_INVOICE_DESCRIPTION_DESC", "t", 0, 4, 0, null),
			array(NULL, NULL, "Generic_Emails", "0", "", "TRANS_GATEWAY_GEN_EMAIL","TRANS_GATEWAY_GEN_EMAIL_DESC", "r", 0, 5, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
			array(NULL, NULL, "Batch_Recurring", "1", "", "TRANS_BATCH_RECURRING","TRANS_BATCH_RECURRING_DESC", "r", 1, 6, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "Testing", "1", "", "TRANS_GATEWAY_TESTING", "TRANS_GATEWAY_TESTING_DESC", "r", 1, 7, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "Gateway_URL", "1", "", "TRANS_GATEWAY_URL", "TRANS_GATEWAY_URL_DESC", "r", 1, 7, 0, array
                    (
                        array(NULL, NULL, "0", "TRANS_LIVE_URL", 0),
                        array(NULL, NULL, "1", "TRANS_TESTING_URL", 1)
                    )),
            array(NULL, NULL, "card_accept_0", "1", "", "TRANS_ACCEPT_VISA", "TRANS_ACCEPT_VISA_DESC", "r", 1, 8, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "card_accept_1", "1", "", "TRANS_ACCEPT_MASTERCARD", "TRANS_ACCEPT_MASTERCARD_DESC", "r", 1, 9, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "card_accept_2", "1", "", "TRANS_ACCEPT_AMEX", "TRANS_ACCEPT_AMEX_DESC", "r", 1, 10, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "card_accept_3", "1", "", "TRANS_ACCEPT_DISCOVER", "TRANS_ACCEPT_DISCOVER_DESC", "r", 1, 11, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "card_accept_4", "1", "", "TRANS_ACCEPT_JCB", "TRANS_ACCEPT_JCB_DESC", "r", 1, 12, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "accept_echeck", "1", "", "TRANS_ACCEPT_ECHECK", "TRANS_ACCEPT_ECHECK_DESC", "r", 1, 13, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            );
		return $defaultConfigParams;
	}

	 /**
	  *
	  * From a child module this function must do the following:
	  *   - Maintain $this->hasExecuted, $this->hasExecutedSuccessfully, $this->timestamp,
	  *     $this->status, $this->accountID
	  *   - Add any queries to the debug list with addDebug()
	  *   - Add any errors to the error list with addError()
	  *   - Return $this->returnData, or the appropriate error constant
	  *
	  * @return  Returns feedback from execution of this Gateway object, or an error constant defined
	  *          at the top of this file.
	  */
	function execute(){
		$this->simulateRefundsForTestURL = 1;
		return $this->runAuthNETProtocol();
	} //execute
	 
} // AuthorizeNet

/* Debug
$debug = "
<module>
  <gateway>
    <authorizenet>
      <params>
        <configGroupName>0</configGroupName>
        <subCommand>charge</subCommand>
        <invoiceID>135</invoiceID>
        <authCode></authCode>
        <transactionCode></transactionCode>
        <paymentDescription>ModernBill Test Service</paymentDescription>
        <paymentAmount>1.54</paymentAmount>
        <paymentMethod>CC</paymentMethod>
        <isRecurring>1</isRecurring>
        <billingAccountID></billingAccountID>
        <clientContactID></clientContactID>
        <billingCardNum>5400000000000005</billingCardNum>
        <billingCardExpYear>2007</billingCardExpYear>
        <billingCardExpMonth>1</billingCardExpMonth>
        <cardCVV2>222</cardCVV2>
        <billingBankName></billingBankName>
        <billingBankAbaCode></billingBankAbaCode>
        <billingBankAccountNum></billingBankAccountNum>
        <billingBankLicenseNum></billingBankLicenseNum>
        <billingBankDOB></billingBankDOB>
        <contactFirstName>Mark</contactFirstName>
        <contactLastName>Garrett</contactLastName>
        <contactCompany>ModernGigabyte</contactCompany>
        <contactAddress1>201 E Jefferson</contactAddress1>
        <contactAddress2>Ste 201</contactAddress2>
        <contactCity>Louisville</contactCity>
        <contactState>KY</contactState>
        <contactZip>40202</contactZip>
        <countriesID>US</countriesID>
        <contactPhone1>502.566.7754</contactPhone1>
        <contactFax>502.566.7724</contactFax>
        <contactEmail>mark@modernbill.com</contactEmail>
      </params>
    </authorizenet>
  </gateway>
</module>
";
$payment =& new AuthorizeNet($debug);
$CONF["debug"]->add("MBAPI Result", htmlspecialchars($payment->getData()));
echo "<pre>".$CONF['debug']->show()."</pre>";
/* */

==> plesk-billing-6.0.3.tar.gz: plesk-billing-6.0.3/plesk-billing/lib-mbapi/include/modules/gateway/authorizenet.php <==
<?php
// +----------------------------------------------------------------------+
// | ModernBill [TM] .:. Client Billing System                            |
// +----------------------------------------------------------------------+
// | Copyright (c) 2001-2006 ModernGigabyte, LLC                          |
// +----------------------------------------------------------------------+
// | This source file is subject to the ModernBill End User License       |
// | Agreement (EULA), that is bundled with this package in the file      |
// | LICENSE, and is available at through the world-wide-web at           |
// | http://www.modernbill.com/extranet/LICENSE.txt                       |
// | If you did not receive a copy of the ModernBill license and are      |
// | unable to obtain it through the world-wide-web, please send a note   |
// | to license@modernbill.com so we can email you a copy immediately.    |
// +----------------------------------------------------------------------+
// | Authors: ModernGigabyte, LLC <info@moderngigabyte.com>               |
// | Support: http://www.modernsupport.com/modernbill/                    |
// +----------------------------------------------------------------------+
// | ModernGigabyte and ModernBill are trademarks of ModernGigabyte, LLC. |
// +----------------------------------------------------------------------+
require_once dirname(__FILE__)."/../../../../lib-tk/shield.php";

require_once mb_path("/lib-mbapi/include/modules/gateway/gateway.php");

/**
 * This class is an instantion of the Gateway class, that executes a command pertaining
 * to comunicating with a payment gateway, in the default case from the database. Pass in
 * only the array parameters that are set.
 *
 *<module>
 * <gateway>
 *  <authorizenet>
 *     <params>
 *       <configGroupName></configGroupName>						(Required: Configuration instance of AuthorizeNet module)
 *       <subCommand>charge</subCommand>       						(Required: One of charge, auth, finalize, refund)
 *       <invoiceID></invoiceID>
 *       <authCode></authCode>										(Required for finalize)
 *       <transactionCode></transactionCode>						(Required for refund)
 *       <paymentDescription></paymentDescription>					(Required)
 *       <paymentAmount></paymentAmount>							(Required: 0.00)
 *       <paymentMethod></paymentMethod>							(Required: CC, echeck)
 *       <isRecurring></isRecurring>								(0,1)
 *       <billingAccountID></billingAccountID>			(Enter either this or billing info below)
 *       <clientContactID></clientContactID>									(Enter either this or contact info below)
 *       <billingCardNum></billingCardNum>
 *       <billingCardExpYear></billingCardExpYear>
 *       <billingCardExpMonth></billingCardExpMonth>
 *       <cardCVV2>222</cardCVV2>
 *       <billingBankName></billingBankName>
 *       <billingBankAbaCode></billingBankAbaCode>
 *       <billingBankAccountNum></billingBankAccountNum>
 *       <billingBankLicenseNum></billingBankLicenseNum>
 *       <billingBankDOB></billingBankDOB>
 *       <contactFirstName></contactFirstName>
 *       <contactLastName></contactLastName>
 *       <contactCompany></contactCompany>
 *       <contactAddress1></contactAddress1>
 *       <contactAddress2></contactAddress2>
 *       <contactCity></contactCity>
 *       <contactState></contactState>
 *       <contactZip></contactZip>
 *       <countriesID></countriesID>
 *       <contactPhone1></contactPhone1>
 *       <contactFax></contactFax>
 *       <contactEmail></contactEmail>
 *     </params>
 *   </authorizenet>
 * </gateway>
 *<module>
 *
 * @package modernbill
 * @subpackage mbapi
 */

$className = "AuthorizeNet";
$GLOBALS["moduleInfo"][$className] = array
(
    "type" => "gateway",
    "status" => "TRANS_STABLE",
    "version" => "1.0.2",
    "gatewaytype" => "1",
    "displayName" => "AuthorizeNet",
    "author" => "Parallels",
    "capabilities" => array(GATEWAY_CHARGE, GATEWAY_AUTHORIZE, GATEWAY_PRIOR_AUTH_CHARGE, GATEWAY_REFUND, GATEWAY_PARTIAL_REFUND, GATEWAY_VOID)
);

class AuthorizeNet extends Gateway {

	/**
	 * Returns the module display for the BluePay module. This includes version number and display name.
	 * the columns in config_params. This array will be looped by SetConfigGroups.
	 *
	 * @return	An array of arrays containing all the display info for the module.
	 */
    function getModuleInfo() {
        return $GLOBALS["moduleInfo"]["AuthorizeNet"];
    }

	/**
	 * Execute the command based upon the given information, and return the result.
	 *
	 * @return  The result of the AuthorizeNet gateway command based upon the given information.
	 */
	 function AuthorizeNet($params){
	 $this->stringRep = "authorizenet";
	 	parent::Gateway($params);

        $moduleInfo = $this->getModuleInfo();

        foreach ($moduleInfo["capabilities"] as $cap){
            $this->capabilities[$cap] = 1;
        }
		$this->version = "1.0.0";
		$this->liveURL = "https://secure.authorize.net/gateway/transact.dll";
		$this->testURL = "https://test.authorize.net/gateway/transact.dll";
	 }
	 
	/**
	 * Returns the default configuration parameters for the BluePay module. The number of elements in each array must me identical to 
	 * the columns in config_params. This array will be looped by SetConfigGroups.
	 * 
	 * @return	An array of arrays containing all the parameters the module uses. 
	 */
	function addDefaultConfigParams() {
		static $defaultConfigParams = array(
			array(NULL, NULL, "Login_ID", "testdrive", "", "TRANS_AUTHNET_LOGINID", "TRANS_AUTHNET_LOGINID_DESC", "t", 1, 1, 0, null),
			array(NULL, NULL, "Password", "testdrive", "", "TRANS_AUTHNET_PASSWORD", "TRANS_AUTHNET_PASSWORD_DESC", "p", 1, 2, 0, null),
			array(NULL, NULL, "Version", "3.1", "", "TRANS_AUTHNET_VERSION","TRANS_AUTHNET_VERSION_DESC", "t", 1, 3, 0, null),
			array(NULL, NULL, "Invoice_Description", "", "", "TRANS_INVOICE_DESCRIPTION", "TRANS_INVOICE_DESCRIPTION_DESC", "t", 0, 4, 0, null),
			array(NULL, NULL, "Generic_Emails", "0", "", "TRANS_GATEWAY_GEN_EMAIL","TRANS_GATEWAY_GEN_EMAIL_DESC", "r", 0, 5, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
			array(NULL, NULL, "Batch_Recurring", "1", "", "TRANS_BATCH_RECURRING","TRANS_BATCH_RECURRING_DESC", "r", 1, 6, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "Testing", "1", "", "TRANS_GATEWAY_TESTING", "TRANS_GATEWAY_TESTING_DESC", "r", 1, 7, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "Gateway_URL", "1", "", "TRANS_GATEWAY_URL", "TRANS_GATEWAY_URL_DESC", "r", 1, 7, 0, array
                    (
                        array(NULL, NULL, "0", "TRANS_LIVE_URL", 0),
                        array(NULL, NULL, "1", "TRANS_TESTING_URL", 1)
                    )),
            array(NULL, NULL, "card_accept_0", "1", "", "TRANS_ACCEPT_VISA", "TRANS_ACCEPT_VISA_DESC", "r", 1, 8, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "card_accept_1", "1", "", "TRANS_ACCEPT_MASTERCARD", "TRANS_ACCEPT_MASTERCARD_DESC", "r", 1, 9, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "card_accept_2", "1", "", "TRANS_ACCEPT_AMEX", "TRANS_ACCEPT_AMEX_DESC", "r", 1, 10, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "card_accept_3", "1", "", "TRANS_ACCEPT_DISCOVER", "TRANS_ACCEPT_DISCOVER_DESC", "r", 1, 11, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "card_accept_4", "1", "", "TRANS_ACCEPT_JCB", "TRANS_ACCEPT_JCB_DESC", "r", 1, 12, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            array(NULL, NULL, "accept_echeck", "1", "", "TRANS_ACCEPT_ECHECK", "TRANS_ACCEPT_ECHECK_DESC", "r", 1, 13, 0, array
                    (
                        array(NULL, NULL, "1", "TRANS_TESTING_YES", 0),
                        array(NULL, NULL, "0", "TRANS_TESTING_NO", 1)
                    )),
            );
		return $defaultConfigParams;
	}

	 /**
	  *
	  * From a child module this function must do the following:
	  *   - Maintain $this->hasExecuted, $this->hasExecutedSuccessfully, $this->timestamp,
	  *     $this->status, $this->accountID
	  *   - Add any queries to the debug list with addDebug()
	  *   - Add any errors to the error list with addError()
	  *   - Return $this->returnData, or the appropriate error constant
	  *
	  * @return  Returns feedback from execution of this Gateway object, or an error constant defined
	  *          at the top of this file.
	  */
	function execute(){
		$this->simulateRefundsForTestURL = 1;
		return $this->runAuthNETProtocol();
	} //execute
	 
} // AuthorizeNet

/* Debug
$debug = "
<module>
  <gateway>
    <authorizenet>
      <params>
        <configGroupName>0</configGroupName>
        <subCommand>charge</subCommand>
        <invoiceID>135</invoiceID>
        <authCode></authCode>
        <transactionCode></transactionCode>
        <paymentDescription>ModernBill Test Service</paymentDescription>
        <paymentAmount>1.54</paymentAmount>
        <paymentMethod>CC</paymentMethod>
        <isRecurring>1</isRecurring>
        <billingAccountID></billingAccountID>
        <clientContactID></clientContactID>
        <billingCardNum>5400000000000005</billingCardNum>
        <billingCardExpYear>2007</billingCardExpYear>
        <billingCardExpMonth>1</billingCardExpMonth>
        <cardCVV2>222</cardCVV2>
        <billingBankName></billingBankName>
        <billingBankAbaCode></billingBankAbaCode>
        <billingBankAccountNum></billingBankAccountNum>
        <billingBankLicenseNum></billingBankLicenseNum>
        <billingBankDOB></billingBankDOB>
        <contactFirstName>Mark</contactFirstName>
        <contactLastName>Garrett</contactLastName>
        <contactCompany>ModernGigabyte</contactCompany>
        <contactAddress1>201 E Jefferson</contactAddress1>
        <contactAddress2>Ste 201</contactAddress2>
        <contactCity>Louisville</contactCity>
        <contactState>KY</contactState>
        <contactZip>40202</contactZip>
        <countriesID>US</countriesID>
        <contactPhone1>502.566.7754</contactPhone1>
        <contactFax>502.566.7724</contactFax>
        <contactEmail>mark@modernbill.com</contactEmail>
      </params>
    </authorizenet>
  </gateway>
</module>
";
$payment = new AuthorizeNet($debug);
$CONF["debug"]->add("MBAPI Result", htmlspecialchars($payment->getData()));
echo "<pre>".$CONF['debug']->show()."</pre>";
/* */
